function [x,J] = fixedesc(x,f,g,options,varargin)

% Steepest descent with constant stepsize
%
% f functional
% g gradient of f
% x variable
% in structure options:
%   maxiter number of iterations, default 100
%   stepsize stepsize of descent, default 1/norm(initial gradient)
%   verbosemode if 1 then display evaluation of f at each step
% varargin additional arguments passed to f and g
%
% returns x variable at the end of minimization
% and J record of function evaluations
%
% author : Joan Glaunès - joan.glaunes@free.fr

maxiter = 100;
G = feval(g,x,varargin{:});
stepsize = 1/norm(G(:));

loadstruct('options');

for iter = 1:maxiter
    x = x - stepsize*G;
    if verbosemode | nargout > 1
        J(iter) = feval(f,x,varargin{:});
    end
    if verbosemode
        disp(['iteration ',num2str(iter),...
                '           fonctional  =  ',num2str(J(iter))]);
    end
    G = feval(g,x,varargin{:});
end
